@@ -34,6 +34,8 @@ enum {
 	CALLBACKS_SAVE_FILE_PNG,
 	CALLBACKS_SAVE_FILE_RS274X,
 	CALLBACKS_SAVE_FILE_DRILL,
+	CALLBACKS_SAVE_FILE_RS274XM,
+	CALLBACKS_SAVE_FILE_DRILLM,
 	CALLBACKS_SAVE_LAYER_AS,
 	
 } CALLBACKS_SAVE_FILE_TYPE;
@@ -70,7 +72,7 @@ void
 callbacks_print_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-void
+gboolean
 callbacks_quit_activate                       (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
