@@ -1,5 +1,5 @@
 /*
- * $Id: common.h,v 1.1 2007/11/26 13:45:06 danmc Exp $
+ * $Id$
  *
  * gEDA - GNU Electronic Design Automation
  * This file is a part of gerbv.
@@ -20,6 +20,11 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
  */
 
+/** \file common.h
+    \brief Contains basic defines for debug messages
+    \ingroup libgerbv
+*/
+
 #ifndef __COMMON_H__
 #define __COMMON_H__
 
