@@ -45,49 +45,48 @@
 #include <cairo.h>
 
 #define dprintf if(DEBUG) printf
-#define PIXEL_ALIGN 1
 
 void
-draw_cairo_line_to (cairo_t *cairoTarget, gdouble x, gdouble y, gboolean adjustByHalf){
+draw_cairo_line_to (cairo_t *cairoTarget, gdouble x, gdouble y, gboolean adjustByHalf, gboolean pixelOutput){
 	gdouble x1 = x, y1 = y;
-#ifdef PIXEL_ALIGN
-	cairo_user_to_device (cairoTarget, &x1, &y1);
-	x1 = round(x1);
-	y1 = round(y1);
-	if (adjustByHalf) {
-		x1 += 0.5;
-		y1 += 0.5;
+	if (pixelOutput) {
+		cairo_user_to_device (cairoTarget, &x1, &y1);
+		x1 = round(x1);
+		y1 = round(y1);
+		if (adjustByHalf) {
+			x1 += 0.5;
+			y1 += 0.5;
+		}
+		cairo_device_to_user (cairoTarget, &x1, &y1);		
 	}
-	cairo_device_to_user (cairoTarget, &x1, &y1);
-#endif
 	cairo_line_to (cairoTarget, x1, y1);
 }
 
 void
-draw_cairo_move_to (cairo_t *cairoTarget, gdouble x, gdouble y, gboolean oddWidth){
+draw_cairo_move_to (cairo_t *cairoTarget, gdouble x, gdouble y, gboolean oddWidth, gboolean pixelOutput){
 	gdouble x1 = x, y1 = y;
-#ifdef PIXEL_ALIGN
-	cairo_user_to_device (cairoTarget, &x1, &y1);
-	x1 = round(x1);
-	y1 = round(y1);
-	if (oddWidth) {
-		x1 += 0.5;
-		y1 += 0.5;
+	if (pixelOutput) {
+		cairo_user_to_device (cairoTarget, &x1, &y1);
+		x1 = round(x1);
+		y1 = round(y1);
+		if (oddWidth) {
+			x1 += 0.5;
+			y1 += 0.5;
+		}
+		cairo_device_to_user (cairoTarget, &x1, &y1);
 	}
-	cairo_device_to_user (cairoTarget, &x1, &y1);
-#endif
 	cairo_move_to (cairoTarget, x1, y1);
 }
 
 void
-draw_cairo_translate_adjust (cairo_t *cairoTarget, gdouble x, gdouble y){
+draw_cairo_translate_adjust (cairo_t *cairoTarget, gdouble x, gdouble y, gboolean pixelOutput){
 	gdouble x1 = x, y1 = y;
-#ifdef PIXEL_ALIGN
-	cairo_user_to_device (cairoTarget, &x1, &y1);
-	x1 = round(x1);
-	y1 = round(y1);
-	cairo_device_to_user (cairoTarget, &x1, &y1);
-#endif
+	if (pixelOutput) {
+		cairo_user_to_device (cairoTarget, &x1, &y1);
+		x1 = round(x1);
+		y1 = round(y1);
+		cairo_device_to_user (cairoTarget, &x1, &y1);
+	}
 	cairo_translate (cairoTarget, x1, y1);
 }
 
@@ -193,16 +192,17 @@ gerbv_draw_circle(cairo_t *cairoTarget, gdouble diameter)
  * Draws a rectangle _centered_ at x,y with sides x_side, y_side
  */
 static void
-gerbv_draw_rectangle(cairo_t *cairoTarget, gdouble width1, gdouble height1)
+gerbv_draw_rectangle(cairo_t *cairoTarget, gdouble width1, gdouble height1, gboolean pixelOutput)
 {
 	gdouble width = width1, height = height1;
-	cairo_user_to_device_distance (cairoTarget, &width, &height);
-	width = round(width);
-	height = round(height);
-	width -= ((int)width % 2);
-	height -= ((int)height % 2);
-	cairo_device_to_user_distance (cairoTarget, &width, &height);
-	
+	if (pixelOutput) {
+		cairo_user_to_device_distance (cairoTarget, &width, &height);
+		width = round(width);
+		height = round(height);
+		width -= ((int)width % 2);
+		height -= ((int)height % 2);
+		cairo_device_to_user_distance (cairoTarget, &width, &height);
+	}
     cairo_rectangle (cairoTarget, - width / 2.0, - height / 2.0, width, height);
     return;
 } /* gerbv_draw_rectangle */
@@ -267,11 +267,11 @@ gerbv_draw_polygon(cairo_t *cairoTarget, gdouble outsideDiameter,
 
 
 static void 
-gerbv_draw_aperature_hole(cairo_t *cairoTarget, gdouble dimensionX, gdouble dimensionY)
+gerbv_draw_aperature_hole(cairo_t *cairoTarget, gdouble dimensionX, gdouble dimensionY, gboolean pixelOutput)
 {
     if (dimensionX) {
 	if (dimensionY) {
-	    gerbv_draw_rectangle (cairoTarget, dimensionX, dimensionY);
+	    gerbv_draw_rectangle (cairoTarget, dimensionX, dimensionY, pixelOutput);
 	} else {
 	    gerbv_draw_circle (cairoTarget, dimensionX);
 	}
@@ -509,10 +509,10 @@ draw_apply_netstate_transformation (cairo_t *cairoTarget, gerbv_netstate_t *stat
 
 void
 draw_render_polygon_object (gerbv_net_t *oldNet, cairo_t *cairoTarget, gdouble sr_x, gdouble sr_y,
-		gerbv_image_t *image, gchar drawMode, gerbv_selection_info_t *selectionInfo ){
+		gerbv_image_t *image, gchar drawMode, gerbv_selection_info_t *selectionInfo, gboolean pixelOutput){
 	gerbv_net_t *currentNet, *polygonStartNet;
 	int haveDrawnFirstFillPoint = 0;
-	gdouble x1,y1,x2,y2,cp_x=0,cp_y=0;
+	gdouble x2,y2,cp_x=0,cp_y=0;
 	
 	haveDrawnFirstFillPoint = FALSE;
 	/* save the first net in the polygon as the "ID" net pointer
@@ -521,8 +521,6 @@ draw_render_polygon_object (gerbv_net_t *oldNet, cairo_t *cairoTarget, gdouble s
 	cairo_new_path(cairoTarget);
 		
 	for (currentNet = oldNet->next; currentNet!=NULL; currentNet = currentNet->next){
-		x1 = currentNet->start_x + sr_x;
-		y1 = currentNet->start_y + sr_y;
 		x2 = currentNet->stop_x + sr_x;
 		y2 = currentNet->stop_y + sr_y;
            
@@ -532,7 +530,7 @@ draw_render_polygon_object (gerbv_net_t *oldNet, cairo_t *cairoTarget, gdouble s
 			cp_y = currentNet->cirseg->cp_y + sr_y;
 		}
 		if (!haveDrawnFirstFillPoint) {
-			draw_cairo_move_to (cairoTarget, x2, y2, FALSE);
+			draw_cairo_move_to (cairoTarget, x2, y2, FALSE, pixelOutput);
 			haveDrawnFirstFillPoint=TRUE;
 			continue;
 		}
@@ -541,7 +539,7 @@ draw_render_polygon_object (gerbv_net_t *oldNet, cairo_t *cairoTarget, gdouble s
 			case GERBV_INTERPOLATION_LINEARx01 :
 			case GERBV_INTERPOLATION_LINEARx001 :
 			case GERBV_INTERPOLATION_LINEARx1 :
-				draw_cairo_line_to (cairoTarget, x2, y2, FALSE);
+				draw_cairo_line_to (cairoTarget, x2, y2, FALSE, pixelOutput);
 				break;
 			case GERBV_INTERPOLATION_CW_CIRCULAR :
 			case GERBV_INTERPOLATION_CCW_CIRCULAR :
@@ -576,7 +574,7 @@ draw_image_to_cairo_target (cairo_t *cairoTarget, gerbv_image_t *image,
 					gdouble pixelWidth,
 					gchar drawMode, gerbv_selection_info_t *selectionInfo,
 					gerbv_render_info_t *renderInfo, gboolean allowOptimization,
- 					gerbv_user_transformation_t transform, gboolean limitPixelSize){
+ 					gerbv_user_transformation_t transform, gboolean pixelOutput){
 	struct gerbv_net *net, *polygonStartNet=NULL;
 	double x1, y1, x2, y2, cp_x=0, cp_y=0;
 	gdouble p1, p2, p3, p4, p5, dx, dy, lineWidth;
@@ -591,7 +589,14 @@ draw_image_to_cairo_target (cairo_t *cairoTarget, gerbv_image_t *image,
 	gdouble criticalRadius;
 	gdouble scaleX = transform.scaleX;
 	gdouble scaleY = transform.scaleY;
-
+	gboolean limitLineWidth = TRUE;
+	gboolean displayPixel = TRUE;
+	// if we are scaling the image at all, ignore the line width checks since scaled up
+	//	lines can still be visible
+	if ((scaleX != 1)||(scaleY != 1)){
+		limitLineWidth = FALSE;
+	}
+	
 	if (transform.mirrorAroundX)
 		scaleY *= -1;
 	if (transform.mirrorAroundY)
@@ -611,7 +616,7 @@ draw_image_to_cairo_target (cairo_t *cairoTarget, gerbv_image_t *image,
 			transform.mirrorAroundX || transform.mirrorAroundY)
 		useOptimizations = FALSE;
 				
-	if (useOptimizations) {
+	if (useOptimizations && pixelOutput) {
 		minX = renderInfo->lowerLeftX;
 		minY = renderInfo->lowerLeftY;
 		maxX = renderInfo->lowerLeftX + (renderInfo->displayWidth /
@@ -638,15 +643,15 @@ draw_image_to_cairo_target (cairo_t *cairoTarget, gerbv_image_t *image,
 		invertPolarity = FALSE;
 		
     if (invertPolarity) {
-    	drawOperatorClear = CAIRO_OPERATOR_OVER;
-    	drawOperatorDark = CAIRO_OPERATOR_CLEAR;
-    	cairo_set_operator (cairoTarget, CAIRO_OPERATOR_OVER);
-    	cairo_paint (cairoTarget);
-    	cairo_set_operator (cairoTarget, CAIRO_OPERATOR_CLEAR);
+		drawOperatorClear = CAIRO_OPERATOR_OVER;
+		drawOperatorDark = CAIRO_OPERATOR_CLEAR;
+		cairo_set_operator (cairoTarget, CAIRO_OPERATOR_OVER);
+		cairo_paint (cairoTarget);
+		cairo_set_operator (cairoTarget, CAIRO_OPERATOR_CLEAR);
     }
     else {
-      drawOperatorClear = CAIRO_OPERATOR_CLEAR;
-    	drawOperatorDark = CAIRO_OPERATOR_OVER;
+		drawOperatorClear = CAIRO_OPERATOR_CLEAR;
+		drawOperatorDark = CAIRO_OPERATOR_OVER;
     }
     /* next, push two cairo states to simulate the first layer and netstate
        translations (these will be popped when another layer or netstate is
@@ -670,11 +675,15 @@ draw_image_to_cairo_target (cairo_t *cairoTarget, gerbv_image_t *image,
 		/* do any rotations */
 		cairo_rotate (cairoTarget, net->layer->rotation);
 		/* handle the layer polarity */
-		if ((net->layer->polarity == GERBV_POLARITY_CLEAR)) {
-			cairo_set_operator (cairoTarget, drawOperatorClear);
+		if ((net->layer->polarity == GERBV_POLARITY_CLEAR)^invertPolarity) {
+			cairo_set_operator (cairoTarget, CAIRO_OPERATOR_CLEAR);
+			drawOperatorClear = CAIRO_OPERATOR_OVER;
+    			drawOperatorDark = CAIRO_OPERATOR_CLEAR;
 		}
 		else {
-			cairo_set_operator (cairoTarget, drawOperatorDark);
+			cairo_set_operator (cairoTarget, CAIRO_OPERATOR_OVER);
+			drawOperatorClear = CAIRO_OPERATOR_CLEAR;
+    			drawOperatorDark = CAIRO_OPERATOR_OVER;
 		}
 		/* check for changes to step and repeat */
 		repeat_X = net->layer->stepAndRepeat.X;
@@ -732,7 +741,7 @@ draw_image_to_cairo_target (cairo_t *cairoTarget, gerbv_image_t *image,
 		double sr_y = repeat_j * repeat_dist_Y;
 		
 		
-		if ((useOptimizations) &&
+		if ((useOptimizations && pixelOutput) &&
 				((net->boundingBox.right+sr_x < minX)
 				|| (net->boundingBox.left+sr_x > maxX)
 				|| (net->boundingBox.top+sr_y < minY)
@@ -769,7 +778,7 @@ draw_image_to_cairo_target (cairo_t *cairoTarget, gerbv_image_t *image,
 		switch (net->interpolation) {
 			case GERBV_INTERPOLATION_PAREA_START :
 				draw_render_polygon_object (net, cairoTarget, sr_x, sr_y, image,
-					drawMode, selectionInfo);
+					drawMode, selectionInfo, pixelOutput);
 				continue;
 			case GERBV_INTERPOLATION_DELETED:
 				continue;
@@ -797,28 +806,22 @@ draw_image_to_cairo_target (cairo_t *cairoTarget, gerbv_image_t *image,
 				/* NOTE: also, make sure all lines are at least 1 pixel wide, so they
 				   always show up at low zoom levels */
 				
-				if ((image->aperture[net->aperture]->parameter[0] < pixelWidth)&&
-				(limitPixelSize))
+				if (limitLineWidth&&((image->aperture[net->aperture]->parameter[0] < pixelWidth)&&
+						(pixelOutput)))
 					criticalRadius = pixelWidth/2.0;
-				/* 
-				else if (image->aperture[net->aperture]->parameter[0] == 0)
-					criticalRadius = pixelWidth/2.0;
-				else if (random() < (RAND_MAX / 10))
-					criticalRadius = pixelWidth/2.0;
-				else
-					break;
-				*/
 				else
 					criticalRadius = image->aperture[net->aperture]->parameter[0]/2.0;
 				lineWidth = criticalRadius*2.0;
 				// convert to a pixel integer
 				cairo_user_to_device_distance (cairoTarget, &lineWidth, &x1);
-				lineWidth = round(lineWidth);
-				if ((int)lineWidth % 2) {
-					oddWidth = TRUE;
-				}
-				else {
-					oddWidth = FALSE;
+				if (pixelOutput) {
+					lineWidth = round(lineWidth);
+					if ((int)lineWidth % 2) {
+						oddWidth = TRUE;
+					}
+					else {
+						oddWidth = FALSE;
+					}
 				}
 				cairo_device_to_user_distance (cairoTarget, &lineWidth, &x1);
 				cairo_set_line_width (cairoTarget, lineWidth);
@@ -833,8 +836,8 @@ draw_image_to_cairo_target (cairo_t *cairoTarget, gerbv_image_t *image,
 
 						switch (image->aperture[net->aperture]->type) {
 							case GERBV_APTYPE_CIRCLE :
-								draw_cairo_move_to (cairoTarget, x1, y1, oddWidth);
-								draw_cairo_line_to (cairoTarget, x2, y2, oddWidth);
+								draw_cairo_move_to (cairoTarget, x1, y1, oddWidth, pixelOutput);
+								draw_cairo_line_to (cairoTarget, x2, y2, oddWidth, pixelOutput);
 								draw_stroke (cairoTarget, drawMode, selectionInfo, image, net);
 								break;
 							case GERBV_APTYPE_RECTANGLE :				
@@ -845,19 +848,19 @@ draw_image_to_cairo_target (cairo_t *cairoTarget, gerbv_image_t *image,
 								if(y1 > y2)
 									dy = -dy;
 								cairo_new_path(cairoTarget);
-								draw_cairo_move_to (cairoTarget, x1 - dx, y1 - dy, FALSE);
-								draw_cairo_line_to (cairoTarget, x1 - dx, y1 + dy, FALSE);
-								draw_cairo_line_to (cairoTarget, x2 - dx, y2 + dy, FALSE);
-								draw_cairo_line_to (cairoTarget, x2 + dx, y2 + dy, FALSE);
-								draw_cairo_line_to (cairoTarget, x2 + dx, y2 - dy, FALSE);
-								draw_cairo_line_to (cairoTarget, x1 + dx, y1 - dy, FALSE);
+								draw_cairo_move_to (cairoTarget, x1 - dx, y1 - dy, FALSE, pixelOutput);
+								draw_cairo_line_to (cairoTarget, x1 - dx, y1 + dy, FALSE, pixelOutput);
+								draw_cairo_line_to (cairoTarget, x2 - dx, y2 + dy, FALSE, pixelOutput);
+								draw_cairo_line_to (cairoTarget, x2 + dx, y2 + dy, FALSE, pixelOutput);
+								draw_cairo_line_to (cairoTarget, x2 + dx, y2 - dy, FALSE, pixelOutput);
+								draw_cairo_line_to (cairoTarget, x1 + dx, y1 - dy, FALSE, pixelOutput);
 								draw_fill (cairoTarget, drawMode, selectionInfo, image, net);
 								break;
 							/* for now, just render ovals or polygons like a circle */
 							case GERBV_APTYPE_OVAL :
 							case GERBV_APTYPE_POLYGON :
-								draw_cairo_move_to (cairoTarget, x1,y1, oddWidth);
-								draw_cairo_line_to (cairoTarget, x2,y2, oddWidth);
+								draw_cairo_move_to (cairoTarget, x1,y1, oddWidth, pixelOutput);
+								draw_cairo_line_to (cairoTarget, x2,y2, oddWidth, pixelOutput);
 								draw_stroke (cairoTarget, drawMode, selectionInfo, image, net);
 								break;
 							/* macros can only be flashed, so ignore any that might be here */
@@ -905,24 +908,37 @@ draw_image_to_cairo_target (cairo_t *cairoTarget, gerbv_image_t *image,
 				p5 = image->aperture[net->aperture]->parameter[4];
 
 				cairo_save (cairoTarget);
-				draw_cairo_translate_adjust(cairoTarget, x2, y2);
+				draw_cairo_translate_adjust(cairoTarget, x2, y2, pixelOutput);
 				
 				switch (image->aperture[net->aperture]->type) {
 					case GERBV_APTYPE_CIRCLE :
 						gerbv_draw_circle(cairoTarget, p1);
-						gerbv_draw_aperature_hole (cairoTarget, p2, p3);
+						gerbv_draw_aperature_hole (cairoTarget, p2, p3, pixelOutput);
 						break;
 					case GERBV_APTYPE_RECTANGLE :
-						gerbv_draw_rectangle(cairoTarget, p1, p2);
-						gerbv_draw_aperature_hole (cairoTarget, p3, p4);
+						// some CAD programs use very thin flashed rectangles to compose
+						//	logos/images, so we must make sure those display here
+						displayPixel = pixelOutput;
+						if (limitLineWidth&&((p1 < pixelWidth)&&
+								(pixelOutput))) {
+							p1 = pixelWidth;
+							displayPixel = FALSE;
+						}
+						if (limitLineWidth&&((p2 < pixelWidth)&&
+								(pixelOutput))) {
+							p2 = pixelWidth;
+							displayPixel = FALSE;
+						}
+						gerbv_draw_rectangle(cairoTarget, p1, p2, displayPixel);
+						gerbv_draw_aperature_hole (cairoTarget, p3, p4, displayPixel);
 						break;
 					case GERBV_APTYPE_OVAL :
 						gerbv_draw_oblong(cairoTarget, p1, p2);
-						gerbv_draw_aperature_hole (cairoTarget, p3, p4);
+						gerbv_draw_aperature_hole (cairoTarget, p3, p4, pixelOutput);
 						break;
 					case GERBV_APTYPE_POLYGON :
 						gerbv_draw_polygon(cairoTarget, p1, p2, p3);
-						gerbv_draw_aperature_hole (cairoTarget, p4, p5);
+						gerbv_draw_aperature_hole (cairoTarget, p4, p5, pixelOutput);
 						break;
 					case GERBV_APTYPE_MACRO :
 						gerbv_draw_amacro(cairoTarget, drawOperatorClear, drawOperatorDark,
