@@ -518,6 +518,9 @@ parse_drillfile(gerb_file_t *fd, gerbv_HID_Attribute *attr_list, int n_attr, int
 							 GERBV_MESSAGE_WARNING);
 			       }
 			   }
+			   else
+			   /* unget the char in case we just advanced past a new line char */
+			   	gerb_ungetc (fd);
 		       }
 		   }
 		   break;
@@ -620,7 +623,6 @@ parse_drillfile(gerb_file_t *fd, gerbv_HID_Attribute *attr_list, int n_attr, int
 				      -1,
 				      string,
 				      GERBV_MESSAGE_NOTE);
-		g_free(string);
 		g_free(tmps);
 		break;
 	    case DRILL_M_NOT_IMPLEMENTED :
@@ -847,7 +849,7 @@ parse_drillfile(gerb_file_t *fd, gerbv_HID_Attribute *attr_list, int n_attr, int
 gboolean
 drill_file_p(gerb_file_t *fd, gboolean *returnFoundBinary)
 {
-    char *buf;
+    char *buf=NULL, *tbuf;
     int len = 0;
     char *letter;
     int ascii;
@@ -861,16 +863,34 @@ drill_file_p(gerb_file_t *fd, gboolean *returnFoundBinary)
     gboolean found_T = FALSE;
     gboolean found_X = FALSE;
     gboolean found_Y = FALSE;
+    gboolean end_comments=FALSE;
  
-    buf = g_malloc(MAXL);
-    if (buf == NULL) 
-	GERB_FATAL_ERROR("malloc buf failed while checking for drill file.\n");
+    tbuf = g_malloc(MAXL);
+    if (tbuf == NULL) 
+		GERB_FATAL_ERROR("malloc buf failed while checking for drill file.\n");
 
-    while (fgets(buf, MAXL, fd->fd) != NULL) {
-	len = strlen(buf);
+    while (fgets(tbuf, MAXL, fd->fd) != NULL) {
+	len = strlen(tbuf);
+	buf=tbuf;
+	/* check for comments at top of file.  */
+	if(!end_comments){
+		if(g_strstr_len(buf, len, ";")!=NULL){/* comments at top of file  */
+			for (i=0;i<len-1;++i){
+				if(buf[i]=='\n' && buf[i+1] != ';' && buf[i+1] != '\r' && buf[i+1] != '\n'){
+					end_comments=TRUE;
+					buf=&tbuf[i+1];	/* set rest of parser to end of comments  */
+					
+				}
+			}
+			if(!end_comments)
+				continue;
+		}			
+		else 
+			end_comments=TRUE;
+	}
 
 	/* First look through the file for indications of its type */
-
+	len = strlen(buf);
 	/* check that file is not binary (non-printing chars) */
 	for (i = 0; i < len; i++) {
 	    ascii = (int) buf[i];
@@ -924,7 +944,7 @@ drill_file_p(gerb_file_t *fd, gboolean *returnFoundBinary)
     } /* while (fgets(buf, MAXL, fd->fd) */
 
     rewind(fd->fd);
-    free(buf);
+    free(tbuf);
     *returnFoundBinary = found_binary;
     
     /* Now form logical expression determining if this is a drill file */
@@ -1675,26 +1695,27 @@ eat_line(gerb_file_t *fd)
     }
 } /* eat_line */
 
-
 /* -------------------------------------------------------------- */
 static char *
 get_line(gerb_file_t *fd)
 {
-    int read = gerb_fgetc(fd);
-    gchar *retstring = "";
-    gchar *tmps = NULL;
+	int read = gerb_fgetc(fd);
+	gchar *retstring;
+	gchar *tmps=g_strdup("");
 
-    while(read != 10 && read != 13) {
-	if (read == EOF) return retstring;
-	retstring = g_strdup_printf("%s%c", retstring, read);
+	while(read != 10 && read != 13) {
+		if (read == EOF)
+			return tmps;
+		retstring = g_strdup_printf("%s%c", tmps, read);
 
-	/* since g_strdup_printf allocates memory, we need to free it */
-	if (tmps)  {
-	    g_free (tmps);
-	    tmps = NULL;
+		/* since g_strdup_printf allocates memory, we need to free it */
+		if (tmps)  {
+			g_free (tmps);
+			tmps = NULL;
+		}
+		tmps = retstring;;
+		read = gerb_fgetc(fd);
 	}
-	tmps = retstring;;
-	read = gerb_fgetc(fd);
-    }
-    return retstring;
+	return tmps;
 } /* get_line */
+
