@@ -4,7 +4,7 @@
  *
  *   Copyright (C) 2000-2002 Stefan Petersen (spe@stacken.kth.se)
  *
- * $Id: gerb_file.c,v 1.28 2008/01/12 04:51:25 danmc Exp $
+ * $Id$
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,11 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
  */
 
+/** \file gerb_file.c
+    \brief File parsing support functions
+    \ingroup libgerbv
+*/
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -38,14 +43,16 @@
 #include <sys/mman.h>
 #endif
 #include <errno.h>
-#include "gerb_error.h"
+
+#include "common.h"
+#include "gerbv.h"
 #include "gerb_file.h"
 
 /* DEBUG printing.  #define DEBUG 1 in config.h to use this fcn. */
 #define dprintf if(DEBUG) printf
 
 gerb_file_t *
-gerb_fopen(char *filename)
+gerb_fopen(char const * filename)
 {
     gerb_file_t *fd;
     struct stat statinfo;
@@ -111,7 +118,7 @@ gerb_fopen(char *filename)
         return NULL;
     }
     
-    fd->fd = fopen(filename, "r");
+    fd->fd = fopen(filename, "rb");
     fd->ptr = 0;
     fd->fileno = fileno(fd->fd);
     if (fstat(fd->fileno, &statinfo) < 0) {
@@ -138,7 +145,7 @@ gerb_fopen(char *filename)
         g_free(fd);
         return NULL;
     }
-    if (fread((void*)fd->data, 1, statinfo.st_size, fd->fd) == 0) {
+    if (fread((void*)fd->data, 1, statinfo.st_size, fd->fd) != statinfo.st_size) {
         fclose(fd->fd);
 	g_free(fd->data);
         g_free(fd);
@@ -270,13 +277,22 @@ gerb_fclose(gerb_file_t *fd)
 
 
 char *
-gerb_find_file(char *filename, char **paths)
+gerb_find_file(char const * filename, char **paths)
 {
     char *curr_path = NULL;
     char *complete_path = NULL;
     int	 i;
 
+#ifdef DEBUG
+    if( DEBUG > 0 ) {
+        for (i = 0; paths[i] != NULL; i++) {
+            printf("%s():  paths[%d] = \"%s\"\n", __FUNCTION__, i, paths[i]);
+        }
+    }
+#endif
+
     for (i = 0; paths[i] != NULL; i++) {
+        dprintf("%s():  Try paths[%d] = \"%s\"\n", __FUNCTION__, i, paths[i]);
 
 	/*
 	 * Environment variables start with a $ sign 
@@ -287,7 +303,7 @@ gerb_find_file(char *filename, char **paths)
 
 	    /* Extract environment name. Remember we start with a $ */
         
-   	    tmp = strchr(paths[i], path_separator);
+   	    tmp = strchr(paths[i], G_DIR_SEPARATOR);
 	    if (tmp == NULL) 
 		len = strlen(paths[i]) - 1;
 	    else
@@ -299,37 +315,57 @@ gerb_find_file(char *filename, char **paths)
 	    env_name[len] = '\0';
 
 	    env_value = getenv(env_name);
-	    if (env_value == NULL) break;
-	    curr_path = (char *)g_malloc(strlen(env_value) + strlen(&paths[i][len + 1]) + 1);
-	    if (curr_path == NULL)
+            dprintf("%s():  Trying \"%s\" = \"%s\" from the environment\n",
+                __FUNCTION__, env_name,
+                env_value == NULL ? "(null)" : env_value);
+
+	    if (env_value == NULL) {
+	      curr_path = NULL;
+	    } else {
+	      curr_path = (char *)g_malloc(strlen(env_value) + strlen(&paths[i][len + 1]) + 1);
+	      if (curr_path == NULL)
 		return NULL;
-	    strcpy(curr_path, env_value);
-	    strcat(curr_path, &paths[i][len + 1]);
-	    g_free(env_name);
+	      strcpy(curr_path, env_value);
+	      strcat(curr_path, &paths[i][len + 1]);
+	      g_free(env_name);
+	    }
 	} else {
 	    curr_path = paths[i];
 	}
 
-	/*
-	 * Build complete path (inc. filename) and check if file exists.
-	 */
-	complete_path = (char *)g_malloc(strlen(curr_path) + strlen(filename) + 2);
-	if (complete_path == NULL)
+	if (curr_path != NULL) {
+	  /*
+	   * Build complete path (inc. filename) and check if file exists.
+	   */
+	  complete_path = (char *)g_malloc(strlen(curr_path) + strlen(filename) + 2);
+	  if (complete_path == NULL)
 	    return NULL;
-	strcpy(complete_path, curr_path);
-	complete_path[strlen(curr_path)] = path_separator;
-	complete_path[strlen(curr_path) + 1] = '\0';
-	strncat(complete_path, filename, strlen(filename));
-
-	if (access(complete_path, R_OK) != -1)
+	  strcpy(complete_path, curr_path);
+	  complete_path[strlen(curr_path)] = G_DIR_SEPARATOR;
+	  complete_path[strlen(curr_path) + 1] = '\0';
+	  strncat(complete_path, filename, strlen(filename));
+	  
+	  if (paths[i][0] == '$') {
+	    g_free(curr_path);
+	    curr_path = NULL;
+	  }
+	  
+	  dprintf("%s():  Tring to access \"%s\"\n", __FUNCTION__,
+		  complete_path);
+	  
+	  if (access(complete_path, R_OK) != -1)
 	    break;
-
-	g_free(complete_path);
-	complete_path = NULL;
+	  
+	  g_free(complete_path);
+	  complete_path = NULL;
+	}
     }
-
+	
     if (complete_path == NULL)
-	errno = ENOENT;
-
+      errno = ENOENT;
+    
+    dprintf("%s():  returning complete_path = \"%s\"\n", __FUNCTION__,
+	    complete_path == NULL ? "(null)" : complete_path);
+    
     return complete_path;
 } /* gerb_find_file */
