@@ -547,10 +547,15 @@ gerbv_render_get_boundingbox(gerbv_project_t *gerbvProject, gerbv_render_size_t
 			* Find the biggest image and use as a size reference
 			*/
 			/* cairo info already has offset calculated into min/max */
+			
 			minX = info->min_x;
 			minY = info->min_y;
 			maxX = info->max_x;
 			maxY = info->max_y;
+			
+			if (!isnormal(minX)||!isnormal(minY)||!isnormal(maxX)||!isnormal(maxY)){
+				continue;
+			}
 			/* transform the bounding box based on the user transform */
 	
 			cairo_matrix_t fullMatrix;
@@ -605,7 +610,7 @@ gerbv_render_zoom_to_fit_display (gerbv_project_t *gerbvProject, gerbv_render_in
 
 	/* if the values aren't sane (probably we have no models loaded), then
 	   put in some defaults */
-	if ((width < 0.01) && (height < 0.01)) {
+	if (!isnormal(width)||!isnormal(height)||((width < 0.01) && (height < 0.01))) {
 		renderInfo->lowerLeftX = 0.0;
 		renderInfo->lowerLeftY = 0.0;
 		renderInfo->scaleFactorX = 200;
@@ -828,7 +833,7 @@ gerbv_render_cairo_set_scale_and_translation(cairo_t *cr, gerbv_render_info_t *r
 
 /* ------------------------------------------------------------------ */
 void
-gerbv_render_layer_to_cairo_target_without_transforming(cairo_t *cr, gerbv_fileinfo_t *fileInfo, gerbv_render_info_t *renderInfo, gboolean limitPixelSize) {
+gerbv_render_layer_to_cairo_target_without_transforming(cairo_t *cr, gerbv_fileinfo_t *fileInfo, gerbv_render_info_t *renderInfo, gboolean pixelOutput) {
 	cairo_set_source_rgba (cr, (double) fileInfo->color.red/G_MAXUINT16,
 		(double) fileInfo->color.green/G_MAXUINT16,
 		(double) fileInfo->color.blue/G_MAXUINT16, 1);
@@ -838,7 +843,7 @@ gerbv_render_layer_to_cairo_target_without_transforming(cairo_t *cr, gerbv_filei
 	
 	draw_image_to_cairo_target (cr, fileInfo->image,
 		1.0/MAX(renderInfo->scaleFactorX, renderInfo->scaleFactorY), DRAW_IMAGE, NULL,
-		renderInfo, TRUE, fileInfo->transform, limitPixelSize);
+		renderInfo, TRUE, fileInfo->transform, pixelOutput);
 	cairo_restore (cr);
 }
 
