@@ -1,3 +1,8 @@
+/** \file icons.h
+    \brief XPM info for the toolbar button icons
+    \ingroup gerbv
+*/
+
 /* -------------------  Zoom tool icon  -------------------------- */
 /* GdkPixbuf RGBA C-Source image dump */
 #ifdef __SUNPRO_C
